Page Menu
Home
FreeBSD
Search
Configure Global Search
Log In
Files
F169323977
D7889.diff
No One
Temporary
Actions
View File
Edit File
Delete File
View Transforms
Subscribe
Mute Notifications
Flag For Later
Award Token
Size
1 KB
Referenced Files
None
Subscribers
None
D7889.diff
View Options
Index: head/sys/dev/hyperv/netvsc/hv_netvsc_drv_freebsd.c
===================================================================
--- head/sys/dev/hyperv/netvsc/hv_netvsc_drv_freebsd.c
+++ head/sys/dev/hyperv/netvsc/hv_netvsc_drv_freebsd.c
@@ -3159,13 +3159,25 @@
* are allocated.
*/
- /* Setup default RSS key. */
- memcpy(rss->rss_key, hn_rss_key_default, sizeof(rss->rss_key));
+ if (!device_is_attached(sc->hn_dev)) {
+ /*
+ * Setup default RSS key and indirect table for the
+ * attach DEVMETHOD. They can be altered later on,
+ * so don't mess them up once this interface is attached.
+ */
+ if (bootverbose) {
+ if_printf(sc->hn_ifp, "setup default RSS key and "
+ "indirect table\n");
+ }
+
+ /* Setup default RSS key. */
+ memcpy(rss->rss_key, hn_rss_key_default, sizeof(rss->rss_key));
- /* Setup default RSS indirect table. */
- /* TODO: Take ndis_rss_caps.ndis_nind into account. */
- for (i = 0; i < NDIS_HASH_INDCNT; ++i)
- rss->rss_ind[i] = i % nchan;
+ /* Setup default RSS indirect table. */
+ /* TODO: Take ndis_rss_caps.ndis_nind into account. */
+ for (i = 0; i < NDIS_HASH_INDCNT; ++i)
+ rss->rss_ind[i] = i % nchan;
+ }
error = hn_rndis_conf_rss(sc);
if (error) {
File Metadata
Details
Attached
Mime Type
text/plain
Expires
Wed, Sep 2, 5:01 AM (28 m, 7 s)
Storage Engine
blob
Storage Format
Raw Data
Storage Handle
37912100
Default Alt Text
D7889.diff (1 KB)
Attached To
Mode
D7889: hyperv/hn: Don't mess up RSS key and indirect table after attachment.
Attached
Detach File
Event Timeline
Log In to Comment